@@ -34,7 +34,7 @@ class Cakework(cakework_pb2_grpc.CakeworkServicer):
         module = importlib.import_module(self.module)
         # TODO do something with the context
         parameters = json.loads(request.parameters)
-        res = getattr(self.module, self.activity)
+        res = getattr(module, self.activity)
         return cakework_pb2.Reply(result=json.dumps(res))
 
 def serve():
