@@ -3,8 +3,8 @@ from __future__ import print_function
 import logging
 
 import grpc
-import cakework_pb2
-import cakework_pb2_grpc
+from cakework import cakework_pb2
+from cakework import cakework_pb2_grpc
 import json
 import sys
 
